==> dorm-1.0.12.tar.gz: example/orm_domain/mutable_entity.dart <==
part of orm_domain;

@Ref('entities.mutable_entity')
class MutableEntity extends Entity {

	//---------------------------------
	//
	// Public properties
	//
	//---------------------------------

	//---------------------------------
	// refClassName
	//---------------------------------

	String get refClassName => 'entities.mutable_entity';

	//---------------------------------
	// insertedBy
	//---------------------------------

	@Property(INSERTEDBY_SYMBOL, 'insertedBy', User)
	static const String INSERTEDBY = 'insertedBy';
	static const Symbol INSERTEDBY_SYMBOL = const Symbol('orm_domain.MutableEntity.insertedBy');

	User insertedBy;

	//---------------------------------
	// insertedOn
	//---------------------------------

	@Property(INSERTEDON_SYMBOL, 'insertedOn', DateTime)
	static const String INSERTEDON = 'insertedOn';
	static const Symbol INSERTEDON_SYMBOL = const Symbol('orm_domain.MutableEntity.insertedOn');

	DateTime insertedOn;

	//---------------------------------
	// updatedBy
	//---------------------------------

	@Property(UPDATEDBY_SYMBOL, 'updatedBy', User)
	static const String UPDATEDBY = 'updatedBy';
	static const Symbol UPDATEDBY_SYMBOL = const Symbol('orm_domain.MutableEntity.updatedBy');

	User updatedBy;

	//---------------------------------
	// updatedOn
	//---------------------------------

	@Property(UPDATEDON_SYMBOL, 'updatedOn', DateTime)
	static const String UPDATEDON = 'updatedOn';
	static const Symbol UPDATEDON_SYMBOL = const Symbol('orm_domain.MutableEntity.updatedOn');

	DateTime updatedOn;

	//---------------------------------
	//
	// Constructor
	//
	//---------------------------------

	MutableEntity() : super();

	static MutableEntity construct() => new MutableEntity();

}

==> dorm-1.0.19.tar.gz: example/orm_domain/mutable_entity.dart <==
part of orm_domain;

@Ref('entities.mutable_entity')
class MutableEntity extends Entity {

	//---------------------------------
	//
	// Public properties
	//
	//---------------------------------

	//---------------------------------
	// refClassName
	//---------------------------------

	String get refClassName => 'entities.mutable_entity';

	//---------------------------------
	// insertedBy
	//---------------------------------

	@Property(INSERTEDBY_SYMBOL, 'insertedBy', User, 'User')
	static const String INSERTEDBY = 'insertedBy';
	static const Symbol INSERTEDBY_SYMBOL = const Symbol('orm_domain.MutableEntity.insertedBy');

	User insertedBy;

	//---------------------------------
	// insertedOn
	//---------------------------------

	@Property(INSERTEDON_SYMBOL, 'insertedOn', DateTime, 'DateTime')
	static const String INSERTEDON = 'insertedOn';
	static const Symbol INSERTEDON_SYMBOL = const Symbol('orm_domain.MutableEntity.insertedOn');

	DateTime insertedOn;

	//---------------------------------
	// updatedBy
	//---------------------------------

	@Property(UPDATEDBY_SYMBOL, 'updatedBy', User, 'User')
	static const String UPDATEDBY = 'updatedBy';
	static const Symbol UPDATEDBY_SYMBOL = const Symbol('orm_domain.MutableEntity.updatedBy');

	User updatedBy;

	//---------------------------------
	// updatedOn
	//---------------------------------

	@Property(UPDATEDON_SYMBOL, 'updatedOn', DateTime, 'DateTime')
	static const String UPDATEDON = 'updatedOn';
	static const Symbol UPDATEDON_SYMBOL = const Symbol('orm_domain.MutableEntity.updatedOn');

	DateTime updatedOn;

	//---------------------------------
	//
	// Constructor
	//
	//---------------------------------

	MutableEntity() : super();

	static MutableEntity construct() => new MutableEntity();

}
